@@ -10,3 +10,8 @@ from saruca_uuv.control_system_layer.Methods import orbit
 from saruca_uuv.sensing_system_layer.Classes import EntityLayer
 from saruca_uuv.sensing_system_layer.Methods import imageProcessing
 from saruca_uuv.sensing_system_layer.Methods import variables
+
+import os
+import sys
+
+sys.path.append(os.path.dirname(os.path.realpath(__file__)))
